@@ -8,6 +8,8 @@ test_that("`fdahclust()` works", {
     x = simulated30_sub$x,
     y = simulated30_sub$y,
     n_clusters = K,
+    warping_class = "affine",
+    metric = "normalized_l2",
     use_verbose = FALSE
   )
   expect_true(is_caps(out))
